PyXMake Developer Guide: PyXMake.VTL.chocolatey Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions
PyXMake.VTL.chocolatey Namespace Reference

## Functions
| run (output=os.getcwd(), verbose=2)
| main (python=sys.executable, **kwargs)

## Detailed Description

    Minimum working example for PyXMake.

    @note: Compile MCODAC for PYTHON using Mingw64/GFortran on windows.
    Created on 25.03.2021

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          -

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.chocolatey.main | ( |  | python = sys.executable,
|  | ** | kwargs )

    Build for a given python executable

Definition at line 98 of file chocolatey.py.

## ◆ run()

PyXMake.VTL.chocolatey.run | ( |  | output = os.getcwd(),
|  |  | verbose = 2 )

    Main function to execute the script.

Definition at line 36 of file chocolatey.py.